Skip to main content Crate fromsoftware_shared_macros Copy item path Source for_all_subclasses A proc macro attribute for defining an extension trait that makes a set of
methods available for all subclasses of a superclass. multi_param Annotates a trait to automatically generate getters and setters that forward
to methods of the same name in various structs. singleton Annotates a struct as a Dantelion2 singleton to be looked up using a single
string argument. Researching A derive macro for fromsoftware_shared::Researching that automatically
makes all unk fields (public or private) available through
Researching::unknown_fields. StepperStates A derive macro that implements the StepperStates trait on a given enum. Subclass A derive macro for fromsoftware_shared::Subclass. Superclass A derive macro for fromsoftware_shared::Superclass.