#[derive(StepperStates)]Expand description
A derive macro that implements the StepperStates trait on a given enum.
- The enum must be exhaustive (represent all states and no more).
- The enum must have a -1 state for inactive steppers.
- The enum must have no gaps in the discriminants.
Safety
The implementer must ensure that the enum is exhaustive as unknown discriminants can be used to trigger undefined behavior. The implementer must ensure that the enum does not have more states than the game defines. Failing to do so will allow for out-of-bound access to the stepper array. The implementer must ensure that the enum discriminants have no gaps. Failing to do so will allow out of bounds access to the stepper array as well as cause unknown discriminants.